@@ -1,3 +1,5 @@
+import math
+
 # geometry
 p = 3.14
 
@@ -16,6 +18,14 @@ def ST(a, h):
     s = 0.5 * (a * h)
     return s
 
+#gcd    
+def gcd(a, b):
+    return math.gcd(a, b)
+
+#lcm
+def lcd(a, b):
+    return math.lcm(a, b)
+
 # operations with π
 
 
